.. pythonGraph documentation master file, created by
   sphinx-quickstart on Tue Sep 17 05:42:05 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pythonGraph's documentation!
=======================================

pythonGraph allows programmers to output graphic images to a window. In
addition, it provides functionality to interact with the user via the mouse and
via individual keystrokes on the keyboard.

You can download pythonGraph using the automated Python package manager, pip::

    pip install --user pythonGraph

Getting Started
---------------
To get started, import the pythonGraph library in your Python file, as shown
below::

    import pythonGraph


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
